@@ -5,9 +5,15 @@
 
 import os
 import configparser
+from platform import system
+stdenv = None
+if system() == "Windows" or system() == "cli":
+    stdenv = os.environ["USERPROFILE"].replace('\\', '/')
 
-
-stdenv = os.environ["USERPROFILE"].replace('\\', '/')
+elif system() == "Linux":
+    stdenv = os.environ["HOME"].replace('\\', '/')
+elif system() == "Darwin":
+    stdenv = os.environ["HOME"].replace('\\', '/')
 cf =configparser.ConfigParser()
 config_p=stdenv+"/.stduino/session/config.cfg"
 if os.path.exists(config_p):
