@@ -641,7 +641,11 @@ class StdPathHandler(FileSystemEventHandler,QWidget):
             if os.path.isdir(item):
                 #d_name=item1.text(0)
                 c_file = item.split("/")
-                if len(c_file)>6:
+
+                if len(c_file)>5:
+                    if c_file[4] == "Projects":
+                        stdinit.project_name = c_file[5]
+                        self.workspace_change()
                     if c_file[5] == "Projects":
                         stdinit.project_name = c_file[6]
                         self.workspace_change()
