@@ -215,30 +215,14 @@ class PioInstall():
                 if (r.status_code == 200):
                     version_data = json.loads(r.text)
                     if (int(version_data['version_id']) != int(res.version_id)):
-                        cmd = "curl -fL https://stduino-generic.pkg.coding.net/stduino_packages/boards/boards.zip?version=latest -o boards.zip"
-                        # res = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE)  # 使用管道
-                        proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, shell=True)
-                        for line in iter(proc.stdout.readline, b''):
-                            try:
-                                s1 = str(line, encoding='utf8')
-                            except:
-                                pass
-                            if not subprocess.Popen.poll(proc) is None:
-                                if line == "":
-                                    break
-                        proc.stdout.close()
-                        cmd = "curl -fL https://stduino-generic.pkg.coding.net/stduino_packages/boards/Custom.zip?version=latest -o Custom.zip"
-                        # res = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE)  # 使用管道
-                        proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, shell=True)
-                        for line in iter(proc.stdout.readline, b''):
-                            try:
-                                s1 = str(line, encoding='utf8')
-                            except:
-                                pass
-                            if not subprocess.Popen.poll(proc) is None:
-                                if line == "":
-                                    break
-                        proc.stdout.close()
+                        url = 'https://stduino-generic.pkg.coding.net/stduino_packages/boards/boards.zip?version=latest'
+                        r = requests.get(url)
+                        with open("boards.zip", "wb") as code:
+                            code.write(r.content)
+                        url = 'https://stduino-generic.pkg.coding.net/stduino_packages/boards/Custom.zip?version=latest'
+                        r = requests.get(url)
+                        with open("Custom.zip", "wb") as code:
+                            code.write(r.content)
                         try:
                             board_p = stdinit.stdenv + "/.platformio/boards"
                             core_p = stdinit.stdenv + "/.platformio/"
@@ -296,35 +280,21 @@ class PioInstall():
                 os.makedirs(src_dir)
             with open(main_path, "w") as fp:
                 fp.write(main_content.strip())
+                fp.close()
             return True
         except:
             stdinit.std_signal_gobal.stdprintln()
+            return False
     def std_board_init(self):
         try:
-            cmd = "curl -fL https://stduino-generic.pkg.coding.net/stduino_packages/boards/boards.zip?version=latest -o boards.zip"
-            # res = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE)  # 使用管道
-            proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, shell=True)
-            for line in iter(proc.stdout.readline, b''):
-                try:
-                    s1 = str(line, encoding='utf8')
-                except:
-                    pass
-                if not subprocess.Popen.poll(proc) is None:
-                    if line == "":
-                        break
-            proc.stdout.close()
-            cmd = "curl -fL https://stduino-generic.pkg.coding.net/stduino_packages/boards/Custom.zip?version=latest -o Custom.zip"
-            # res = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE)  # 使用管道
-            proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, shell=True)
-            for line in iter(proc.stdout.readline, b''):
-                try:
-                    s1 = str(line, encoding='utf8')
-                except:
-                    pass
-                if not subprocess.Popen.poll(proc) is None:
-                    if line == "":
-                        break
-            proc.stdout.close()
+            url = 'https://stduino-generic.pkg.coding.net/stduino_packages/boards/boards.zip?version=latest'
+            r = requests.get(url)
+            with open("boards.zip", "wb") as code:
+                code.write(r.content)
+            url = 'https://stduino-generic.pkg.coding.net/stduino_packages/boards/Custom.zip?version=latest'
+            r = requests.get(url)
+            with open("Custom.zip", "wb") as code:
+                code.write(r.content)
             try:
                 board_p = stdinit.stdenv + "/.platformio/boards"
                 core_p = stdinit.stdenv + "/.platformio/"
@@ -385,7 +355,7 @@ class PioInstall():
                     s1 = str(line, encoding='gbk')
                 except:
                     s1 = str(line)
-                print(s1)
+                #print(s1)
                 if not subprocess.Popen.poll(proc) is None:
                     if line == "":
                         break
@@ -401,7 +371,7 @@ class PioInstall():
             for line in iter(proc.stdout.readline, b''):
                 try:
                     s1 = str(line, encoding='gbk')
-                    print(s1)
+                    #print(s1)
                     # if "SUCCESS" in s1:
                     #     init_ok=1
                 except:
