@@ -360,7 +360,19 @@ class StDebug(QWidget):
     def piodebug(self,t,tt):#stdinit.stdenv + "/.stduino/packages/pioenv/Scripts/pio
         try:
             self.debug_sig.emit(0)  # 指令发送进行关闭时触发
-            pio_env = '"' + stdinit.stdenv + "/.stduino/packages/pioenv/Scripts/pio" + '"'
+            if stdinit.platform_is == "Win":
+                pio_env = '"' + stdinit.stdenv + "/.stduino/packages/pioenv/Scripts/pio" + '"'
+
+            elif stdinit.platform_is == "Linux":
+                pio_env = '"' + stdinit.stdenv + "/.stduino/packages/pioenv/bin/pio" + '"'
+
+
+            elif stdinit.platform_is == "Darwin":
+                pio_env = '"' + stdinit.stdenv + "/.stduino/packages/pioenv/bin/pio" + '"'
+            else:
+                return 0
+
+
             piogdb_path = pio_env+" debug -d " +'"' +  stdinit.projects_dir+ stdinit.project_name+ '"' + " --interface=gdb --interpreter mi -x .pioinit"#--interpreter mi
             self.proc = subprocess.Popen(piogdb_path, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, shell=True,
                                          stdin=subprocess.PIPE)
